@@ -1,12 +1,12 @@
 from typing import Callable
 
-from chocs.http_request import HttpRequest
-from chocs.http_response import HttpResponse
+from chocs.http.http_request import HttpRequest
+from chocs.http.http_response import HttpResponse
 from chocs.middleware.middleware import MiddlewarePipeline
 from chocs.routing import Route
-
 from .aws import AwsServerlessFunction
 from .serverless import IS_AWS_ENVIRONMENT, ServerlessFunction
+from functools import update_wrapper
 
 
 def create_serverless_function(
@@ -16,9 +16,9 @@ def create_serverless_function(
 ) -> Callable:
 
     if IS_AWS_ENVIRONMENT:
-        return AwsServerlessFunction(func, route, middleware_pipeline)
+        return update_wrapper(AwsServerlessFunction(func, route, middleware_pipeline), func)
 
-    return ServerlessFunction(func, route, middleware_pipeline)
+    return update_wrapper(ServerlessFunction(func, route, middleware_pipeline), func)
 
 
 __all__ = ["create_serverless_function"]
