@@ -1,7 +1,7 @@
 from typing import Callable
 
-from .http_request import HttpRequest
-from .http_response import HttpResponse
+from chocs.http.http_request import HttpRequest
+from chocs.http.http_response import HttpResponse
 
 HttpHandlerFunction = Callable[[HttpRequest], HttpResponse]
 
